-- -----------------------------------------------------------------------
-- hsqldb SQL script for schema default
-- -----------------------------------------------------------------------


drop table ID_TABLE if exists;

-- -----------------------------------------------------------------------
-- ID_TABLE
-- -----------------------------------------------------------------------
CREATE TABLE ID_TABLE
(
    ID_TABLE_ID INTEGER NOT NULL,
    TABLE_NAME VARCHAR(255) NOT NULL,
    NEXT_ID INTEGER,
    QUANTITY INTEGER,
    PRIMARY KEY(ID_TABLE_ID),
    CONSTRAINT ID_TABLE_UQ_1 UNIQUE(TABLE_NAME)
);


